@@ -67,8 +67,9 @@ Archive = R6Class("Archive",
     #'
     #' @param ... (ignored).
     print = function() {
-      catf(format(self))
-      print(self$data[, setdiff(names(self$data), "x_domain"), with = FALSE], digits = 2)
+      msg_h = if (is.na(self$label)) "" else paste0(" - ", self$label)
+      cat_cli(cli_h1("{.cls {class(self)[1L]}}{msg_h}"))
+      print(as.data.table(self, unnest = "x_domain"), digits = 1)
     },
 
     #' @description
