@@ -32,7 +32,7 @@ OptimizerAsyncDesignPoints = R6Class("OptimizerAsyncDesignPoints",
         id = "design_points",
         param_set = param_set,
         param_classes = c("ParamLgl", "ParamInt", "ParamDbl", "ParamFct", "ParamUty"),
-        properties = c("dependencies", "single-crit", "multi-crit"),
+        properties = c("dependencies", "single-crit", "multi-crit", "async"),
         packages = "rush",
         label = "Asynchronous Design Points",
         man = "bbotk::mlr_optimizers_async_design_points"
