@@ -25,7 +25,7 @@ OptimizerAsyncRandomSearch = R6Class("OptimizerAsyncRandomSearch",
         id = "async_random_search",
         param_set = ps(),
         param_classes = c("ParamLgl", "ParamInt", "ParamDbl", "ParamFct"),
-        properties = c("dependencies", "single-crit", "multi-crit"),
+        properties = c("dependencies", "single-crit", "multi-crit", "async"),
         packages = "rush",
         label = "Asynchronous Random Search",
         man = "bbotk::mlr_optimizers_random_search"
