@@ -76,8 +76,11 @@ TerminatorCombo = R6Class("TerminatorCombo",
     #' @param ... (ignored).
     print = function(...) {
       super$print(...)
-      catf(str_indent("* Terminators:", paste(map_chr(self$terminators, format),
-        collapse = ",")))
+
+      terminators = map_chr(self$terminators, function(t) {class(t)[1L]})
+      msg_trms = cli_vec(lapply(terminators, function(trm) format_inline('{.cls {trm}}')),
+                         style = list(last = ' and ', sep = ', '))
+      cat_cli(cli_li("Terminators: {msg_trms}"))
     },
 
     #' @description
